@@ -17,7 +17,6 @@
 #include "zypp/parser/xml/XmlEscape.h"
 
 #include "zypp/RepoInfo.h"
-#include "zypp/Glob.h"
 #include "zypp/TriBool.h"
 #include "zypp/Pathname.h"
 #include "zypp/ZConfig.h"
@@ -44,9 +43,9 @@ namespace zypp
   struct RepoInfo::Impl
   {
     Impl()
-      : _rawGpgCheck( indeterminate )
-      , _rawRepoGpgCheck( indeterminate )
-      , _rawPkgGpgCheck( indeterminate )
+      : _gpgCheck( indeterminate )
+      , _repoGpgCheck( indeterminate )
+      , _pkgGpgCheck( indeterminate )
       , _validRepoSignature( indeterminate )
       ,	keeppackages(indeterminate)
       , _mirrorListForceMetalink(false)
@@ -72,22 +71,8 @@ namespace zypp
     }
 
   public:
-    /** Path to a license tarball in case it exists in the repo. */
     Pathname licenseTgz() const
-    {
-      Pathname ret;
-      if ( !metadataPath().empty() )
-      {
-	filesystem::Glob g;
-	g.add( metadataPath() / path / "repodata/*license.tar.gz" );
-	if ( g.empty() )
-	  g.add( metadataPath() / path / "license.tar.gz" );
-
-	if ( !g.empty() )
-	  ret = *g.begin();
-      }
-      return ret;
-    }
+    { return metadatapath.empty() ? Pathname() : metadatapath / path / "license.tar.gz"; }
 
     const RepoVariablesReplacedUrlList & baseUrls() const
     {
@@ -95,8 +80,8 @@ namespace zypp
       if ( _baseUrls.empty() && ! mlurl.asString().empty() )
       {
         emptybaseurls = true;
-        DBG << "MetadataPath: " << metadataPath() << endl;
-	repo::RepoMirrorList rmurls( mlurl, metadataPath(), _mirrorListForceMetalink );
+        DBG << "MetadataPath: " << metadatapath << endl;
+	repo::RepoMirrorList rmurls( mlurl, metadatapath, _mirrorListForceMetalink );
 	_baseUrls.raw().insert( _baseUrls.raw().end(), rmurls.getUrls().begin(), rmurls.getUrls().end() );
       }
       return _baseUrls;
@@ -124,14 +109,14 @@ namespace zypp
 
     bool hasContent() const
     {
-      if ( !_keywords.first && ! metadataPath().empty() )
+      if ( !_keywords.first && ! metadatapath.empty() )
       {
 	// HACK directly check master index file until RepoManager offers
 	// some content probing and zypper uses it.
 	/////////////////////////////////////////////////////////////////
-	MIL << "Empty keywords...." << metadataPath() << endl;
+	MIL << "Empty keywords...." << metadatapath << endl;
 	Pathname master;
-	if ( PathInfo( (master=metadataPath()/"/repodata/repomd.xml") ).isFile() )
+	if ( PathInfo( (master=metadatapath/"/repodata/repomd.xml") ).isFile() )
 	{
 	  //MIL << "GO repomd.." << endl;
 	  xml::Reader reader( master );
@@ -142,7 +127,7 @@ namespace zypp
 	  }
 	  _keywords.first = true;	// valid content in _keywords even if empty
 	}
-	else if ( PathInfo( (master=metadataPath()/"/content") ).isFile() )
+	else if ( PathInfo( (master=metadatapath/"/content") ).isFile() )
 	{
 	  //MIL << "GO content.." << endl;
 	  iostr::forEachLine( InputStream( master ),
@@ -170,19 +155,18 @@ namespace zypp
     bool hasContent( const std::string & keyword_r ) const
     { return( hasContent() && _keywords.second.find( keyword_r ) != _keywords.second.end() ); }
 
-    /** Signature check result needs to be stored/retrieved from _metadataPath.
+    /** Signature check result needs to be stored/retrieved from _metadatapath.
      * Don't call them from outside validRepoSignature/setValidRepoSignature
      */
     //@{
     TriBool internalValidRepoSignature() const
     {
-      if ( ! indeterminate(_validRepoSignature) )
-	return _validRepoSignature;
+      if ( ! indeterminate(_validRepoSignature) )		return _validRepoSignature;
       // check metadata:
-      if ( ! metadataPath().empty() )
+      if ( ! metadatapath.empty() )
       {
-	// A missing ".repo_gpgcheck" might be plaindir(no Downloader) or not yet refreshed signed repo!
-	TriBool linkval = triBoolFromPath( metadataPath() / ".repo_gpgcheck" );
+	//TODO: a missing ".repo_gpgcheck" might be plaindir(no Downloader) or not yet refreshed signed repo!
+	TriBool linkval = triBoolFromPath( metadatapath / ".repo_gpgcheck" );
 	return linkval;
       }
       return indeterminate;
@@ -190,9 +174,9 @@ namespace zypp
 
     void internalSetValidRepoSignature( TriBool value_r )
     {
-      if ( PathInfo(metadataPath()).isDir() )
+      if ( PathInfo(metadatapath).isDir() )
       {
-	Pathname gpgcheckFile( metadataPath() / ".repo_gpgcheck" );
+	Pathname gpgcheckFile( metadatapath / ".repo_gpgcheck" );
 	if ( PathInfo(gpgcheckFile).isExist() )
 	{
 	  TriBool linkval( indeterminate );
@@ -206,30 +190,12 @@ namespace zypp
       _validRepoSignature = value_r;
     }
 
-    /** We definitely have a symlink pointing to "indeterminate" (for repoGpgCheckIsMandatory)?
-     * I.e. user accepted the unsigned repo in Downloader. A test whether `internalValidRepoSignature`
-     * is indeterminate would include not yet checked repos, which is unwanted here.
-     */
-    bool internalUnsignedConfirmed() const
-    {
-      TriBool linkval( true );	// want to see it being switched to indeterminate
-      return triBoolFromPath( metadataPath() / ".repo_gpgcheck", linkval ) && indeterminate(linkval);
-    }
-
     bool triBoolFromPath( const Pathname & path_r, TriBool & ret_r ) const
     {
       static const Pathname truePath( "true" );
       static const Pathname falsePath( "false" );
       static const Pathname indeterminatePath( "indeterminate" );
-
-      // Quiet readlink;
-      static const ssize_t bufsiz = 63;
-      static char buf[bufsiz+1];
-      ssize_t ret = ::readlink( path_r.c_str(), buf, bufsiz );
-      buf[ret == -1 ? 0 : ret] = '\0';
-
-      Pathname linkval( buf );
-
+      Pathname linkval( filesystem::readlink( path_r ) );
       bool known = true;
       if ( linkval == truePath )
 	ret_r = true;
@@ -247,27 +213,10 @@ namespace zypp
 
     //@}
 
-  private:
-    TriBool _rawGpgCheck;	///< default gpgcheck behavior: Y/N/ZConf
-    TriBool _rawRepoGpgCheck;	///< need to check repo sign.: Y/N/(ZConf(Y/N/gpgCheck))
-    TriBool _rawPkgGpgCheck;	///< need to check pkg sign.: Y/N/(ZConf(Y/N/gpgCheck))
-
   public:
-    TriBool rawGpgCheck() const			{ return _rawGpgCheck; }
-    TriBool rawRepoGpgCheck() const		{ return _rawRepoGpgCheck; }
-    TriBool rawPkgGpgCheck() const		{ return _rawPkgGpgCheck; }
-
-    void rawGpgCheck( TriBool val_r )		{ _rawGpgCheck = val_r; }
-    void rawRepoGpgCheck( TriBool val_r )	{ _rawRepoGpgCheck = val_r; }
-    void rawPkgGpgCheck( TriBool val_r )	{ _rawPkgGpgCheck = val_r; }
-
-    bool cfgGpgCheck() const
-    { return indeterminate(_rawGpgCheck) ? ZConfig::instance().gpgCheck() : (bool)_rawGpgCheck; }
-    TriBool cfgRepoGpgCheck() const
-    { return indeterminate(_rawGpgCheck) && indeterminate(_rawRepoGpgCheck) ? ZConfig::instance().repoGpgCheck() : _rawRepoGpgCheck; }
-    TriBool cfgPkgGpgCheck() const
-    { return indeterminate(_rawGpgCheck) && indeterminate(_rawPkgGpgCheck) ? ZConfig::instance().pkgGpgCheck() : _rawPkgGpgCheck; }
-
+    TriBool _gpgCheck;		///< default gpgcheck behavior: Y/N/ZConf
+    TriBool _repoGpgCheck;	///< need to check repo sign.: Y/N/(ZConf(Y/N/gpgCheck))
+    TriBool _pkgGpgCheck;	///< need to check pkg sign.: Y/N/(ZConf(Y/N/gpgCheck && no valid repo sign.))
   private:
     TriBool _validRepoSignature;///< have  signed and valid repo metadata
   public:
@@ -278,38 +227,13 @@ namespace zypp
     Pathname path;
     std::string service;
     std::string targetDistro;
-
-    void metadataPath( Pathname new_r )
-    { _metadataPath = std::move( new_r ); }
-
-    void packagesPath( Pathname new_r )
-    { _packagesPath = std::move( new_r ); }
-
-    bool usesAutoMethadataPaths() const
-    { return str::hasSuffix( _metadataPath.asString(), "/%AUTO%" ); }
-
-    Pathname metadataPath() const
-    {
-      if ( usesAutoMethadataPaths() )
-	return _metadataPath.dirname() / "%RAW%";
-      return _metadataPath;
-    }
-
-    Pathname packagesPath() const
-    {
-      if ( _packagesPath.empty() && usesAutoMethadataPaths() )
-	return _metadataPath.dirname() / "%PKG%";
-      return _packagesPath;
-    }
-
+    Pathname metadatapath;
+    Pathname packagespath;
     DefaultIntegral<unsigned,defaultPriority> priority;
     mutable bool emptybaseurls;
     repo::RepoVariablesUrlReplacer replacer;
 
   private:
-    Pathname _metadataPath;
-    Pathname _packagesPath;
-
     mutable RepoVariablesReplacedUrlList _baseUrls;
     mutable std::pair<FalseBool, std::set<std::string> > _keywords;
 
@@ -357,115 +281,56 @@ namespace zypp
 
 
   bool RepoInfo::gpgCheck() const
-  { return _pimpl->cfgGpgCheck(); }
+  { return indeterminate(_pimpl->_gpgCheck) ? ZConfig::instance().gpgCheck() : (bool)_pimpl->_gpgCheck; }
 
   void RepoInfo::setGpgCheck( TriBool value_r )
-  { _pimpl->rawGpgCheck( value_r ); }
+  { _pimpl->_gpgCheck = value_r; }
 
   void RepoInfo::setGpgCheck( bool value_r ) // deprecated legacy and for squid
   { setGpgCheck( TriBool(value_r) ); }
 
 
   bool RepoInfo::repoGpgCheck() const
-  { return gpgCheck() || _pimpl->cfgRepoGpgCheck(); }
-
-  bool RepoInfo::repoGpgCheckIsMandatory() const
   {
-    bool ret = ( gpgCheck() && indeterminate(_pimpl->cfgRepoGpgCheck()) ) || _pimpl->cfgRepoGpgCheck();
-    if ( ret && _pimpl->internalUnsignedConfirmed() )	// relax if unsigned repo was confirmed in the past
-      ret = false;
-    return ret;
+    if ( ! indeterminate(_pimpl->_repoGpgCheck) )		return _pimpl->_repoGpgCheck;
+    if ( ! indeterminate(ZConfig::instance().repoGpgCheck()) )	return ZConfig::instance().repoGpgCheck();
+    return gpgCheck();	// no preference: follow gpgCheck
   }
 
   void RepoInfo::setRepoGpgCheck( TriBool value_r )
-  { _pimpl->rawRepoGpgCheck( value_r ); }
+  { _pimpl->_repoGpgCheck = value_r; }
 
 
   bool RepoInfo::pkgGpgCheck() const
-  { return _pimpl->cfgPkgGpgCheck() || ( gpgCheck() && !bool(validRepoSignature())/*enforced*/ ) ; }
-
-  bool RepoInfo::pkgGpgCheckIsMandatory() const
-  { return _pimpl->cfgPkgGpgCheck() || ( gpgCheck() && indeterminate(_pimpl->cfgPkgGpgCheck()) && !bool(validRepoSignature())/*enforced*/ ); }
+  {
+    if ( ! indeterminate(_pimpl->_pkgGpgCheck) )		return _pimpl->_pkgGpgCheck;
+    if ( ! indeterminate(ZConfig::instance().pkgGpgCheck()) )	return ZConfig::instance().pkgGpgCheck();
+    // no preference: follow gpgCheck and check package if repo signature not available or not checked
+    return gpgCheck() && ( !repoGpgCheck() || !(bool)validRepoSignature() );	// !(bool)TriBool ==> false or indeterminate
+  }
 
   void RepoInfo::setPkgGpgCheck( TriBool value_r )
-  { _pimpl->rawPkgGpgCheck( value_r ); }
-
+  { _pimpl->_pkgGpgCheck = value_r; }
 
   void RepoInfo::getRawGpgChecks( TriBool & g_r, TriBool & r_r, TriBool & p_r ) const
   {
-    g_r = _pimpl->rawGpgCheck();
-    r_r = _pimpl->rawRepoGpgCheck();
-    p_r = _pimpl->rawPkgGpgCheck();
+    g_r = _pimpl->_gpgCheck;
+    r_r = _pimpl->_repoGpgCheck;
+    p_r = _pimpl->_pkgGpgCheck;
   }
 
-
   TriBool RepoInfo::validRepoSignature() const
   {
-    TriBool ret( _pimpl->internalValidRepoSignature() );
-    if ( ret && !repoGpgCheck() ) ret = false;	// invalidate any old signature if repoGpgCheck is off
+    TriBool ret = _pimpl->internalValidRepoSignature();
+    // keep indeterminate(=unsigned) but invalidate any signature if !repoGpgCheck
+    if ( !indeterminate(ret) && !repoGpgCheck() )
+      ret = false;
     return ret;
   }
 
   void RepoInfo::setValidRepoSignature( TriBool value_r )
   { _pimpl->internalSetValidRepoSignature( value_r ); }
 
-  ///////////////////////////////////////////////////////////////////
-  namespace
-  {
-    inline bool changeGpgCheckTo( TriBool & lhs, TriBool rhs )
-    { if ( ! sameTriboolState( lhs, rhs ) ) { lhs = rhs; return true; } return false; }
-
-    inline bool changeGpgCheckTo( TriBool ogpg[3], TriBool g, TriBool r, TriBool p )
-    {
-      bool changed = false;
-      if ( changeGpgCheckTo( ogpg[0], g ) ) changed = true;
-      if ( changeGpgCheckTo( ogpg[1], r ) ) changed = true;
-      if ( changeGpgCheckTo( ogpg[2], p ) ) changed = true;
-      return changed;
-    }
-  } // namespace
-  ///////////////////////////////////////////////////////////////////
-  bool RepoInfo::setGpgCheck( GpgCheck mode_r )
-  {
-    TriBool ogpg[3];	// Gpg RepoGpg PkgGpg
-    getRawGpgChecks( ogpg[0], ogpg[1], ogpg[2] );
-
-    bool changed = false;
-    switch ( mode_r )
-    {
-      case GpgCheck::On:
-	changed = changeGpgCheckTo( ogpg, true,          indeterminate, indeterminate );
-	break;
-      case GpgCheck::Strict:
-	changed = changeGpgCheckTo( ogpg, true,          true,          true          );
-	break;
-      case GpgCheck::AllowUnsigned:
-	changed = changeGpgCheckTo( ogpg, true,          false,         false         );
-	break;
-      case GpgCheck::AllowUnsignedRepo:
-	changed = changeGpgCheckTo( ogpg, true,          false,         indeterminate );
-	break;
-      case GpgCheck::AllowUnsignedPackage:
-	changed = changeGpgCheckTo( ogpg, true,          indeterminate, false         );
-	break;
-      case GpgCheck::Default:
-	changed = changeGpgCheckTo( ogpg, indeterminate, indeterminate, indeterminate );
-	break;
-      case GpgCheck::Off:
-	changed = changeGpgCheckTo( ogpg, false,         indeterminate, indeterminate );
-	break;
-      case GpgCheck::indeterminate:	// no change
-	break;
-    }
-
-    if ( changed )
-    {
-      setGpgCheck    ( ogpg[0] );
-      setRepoGpgCheck( ogpg[1] );
-      setPkgGpgCheck ( ogpg[2] );
-    }
-    return changed;
-  }
 
   void RepoInfo::setMirrorListUrl( const Url & url_r )	// Raw
   { _pimpl->_mirrorListUrl.raw() = url_r; _pimpl->_mirrorListForceMetalink = false; }
@@ -510,10 +375,10 @@ namespace zypp
 
 
   void RepoInfo::setMetadataPath( const Pathname &path )
-  { _pimpl->metadataPath( path ); }
+  { _pimpl->metadatapath = path; }
 
   void RepoInfo::setPackagesPath( const Pathname &path )
-  { _pimpl->packagesPath( path ); }
+  { _pimpl->packagespath = path; }
 
   void RepoInfo::setKeepPackages( bool keep )
   { _pimpl->keeppackages = keep; }
@@ -528,13 +393,10 @@ namespace zypp
   { return indeterminate(_pimpl->keeppackages) ? false : (bool)_pimpl->keeppackages; }
 
   Pathname RepoInfo::metadataPath() const
-  { return _pimpl->metadataPath(); }
+  { return _pimpl->metadatapath; }
 
   Pathname RepoInfo::packagesPath() const
-  { return _pimpl->packagesPath(); }
-
-  bool RepoInfo::usesAutoMethadataPaths() const
-  { return _pimpl->usesAutoMethadataPaths(); }
+  { return _pimpl->packagespath; }
 
   repo::RepoType RepoInfo::type() const
   { return _pimpl->type; }
@@ -612,7 +474,8 @@ namespace zypp
 
   bool RepoInfo::hasLicense() const
   {
-    return !_pimpl->licenseTgz().empty();
+    Pathname licenseTgz( _pimpl->licenseTgz() );
+    return ! licenseTgz.empty() &&  PathInfo(licenseTgz).isFile();
   }
 
   bool RepoInfo::needToAcceptLicense() const
@@ -620,8 +483,8 @@ namespace zypp
     static const std::string noAcceptanceFile = "no-acceptance-needed\n";
     bool accept = true;
 
-    const Pathname & licenseTgz( _pimpl->licenseTgz() );
-    if ( licenseTgz.empty() )
+    Pathname licenseTgz( _pimpl->licenseTgz() );
+    if ( licenseTgz.empty() || ! PathInfo( licenseTgz ).isFile() )
       return false;     // no licenses at all
 
     ExternalProgram::Arguments cmd;
@@ -688,8 +551,8 @@ namespace zypp
 
   LocaleSet RepoInfo::getLicenseLocales() const
   {
-    const Pathname & licenseTgz( _pimpl->licenseTgz() );
-    if ( licenseTgz.empty() )
+    Pathname licenseTgz( _pimpl->licenseTgz() );
+    if ( licenseTgz.empty() || ! PathInfo( licenseTgz ).isFile() )
       return LocaleSet();
 
     ExternalProgram::Arguments cmd;
@@ -743,10 +606,10 @@ namespace zypp
 
     // Yes No Default(Y) Default(N)
 #define OUTS(T,B) ( indeterminate(T) ? (std::string("D(")+(B?"Y":"N")+")") : ((bool)T?"Y":"N") )
-    str << "- gpgcheck    : " << OUTS(_pimpl->rawGpgCheck(),gpgCheck())
-                              << " repo" << OUTS(_pimpl->rawRepoGpgCheck(),repoGpgCheck()) << (repoGpgCheckIsMandatory() ? "* ": " " )
-			      << "sig" << asString( validRepoSignature(), "?", "Y", "N" )
-			      << " pkg" << OUTS(_pimpl->rawPkgGpgCheck(),pkgGpgCheck()) << (pkgGpgCheckIsMandatory() ? "* ": " " )
+    str << "- gpgcheck    : " << OUTS(_pimpl->_gpgCheck,gpgCheck())
+                              << " repo" << OUTS(_pimpl->_repoGpgCheck,repoGpgCheck())
+			      << " sig" << asString( validRepoSignature(), "?", "Y", "N" )
+			      << " pkg" << OUTS(_pimpl->_pkgGpgCheck,pkgGpgCheck())
 			      << std::endl;
 #undef OUTS
 
@@ -760,7 +623,6 @@ namespace zypp
 
     strif( "- service     : ", service() );
     strif( "- targetdistro: ", targetDistribution() );
-    strif( "- filePath:     ", filepath().asString() );
     strif( "- metadataPath: ", metadataPath().asString() );
     strif( "- packagesPath: ", packagesPath().asString() );
 
@@ -793,14 +655,14 @@ namespace zypp
     if ( priority() != defaultPriority() )
       str << "priority=" << priority() << endl;
 
-    if ( ! indeterminate(_pimpl->rawGpgCheck()) )
-      str << "gpgcheck=" << (_pimpl->rawGpgCheck() ? "1" : "0") << endl;
+    if ( ! indeterminate(_pimpl->_gpgCheck) )
+      str << "gpgcheck=" << (_pimpl->_gpgCheck ? "1" : "0") << endl;
 
-    if ( ! indeterminate(_pimpl->rawRepoGpgCheck()) )
-      str << "repo_gpgcheck=" << (_pimpl->rawRepoGpgCheck() ? "1" : "0") << endl;
+    if ( ! indeterminate(_pimpl->_repoGpgCheck) )
+      str << "repo_gpgcheck=" << (_pimpl->_repoGpgCheck ? "1" : "0") << endl;
 
-    if ( ! indeterminate(_pimpl->rawPkgGpgCheck()) )
-      str << "pkg_gpgcheck=" << (_pimpl->rawPkgGpgCheck() ? "1" : "0") << endl;
+    if ( ! indeterminate(_pimpl->_pkgGpgCheck) )
+      str << "pkg_gpgcheck=" << (_pimpl->_pkgGpgCheck ? "1" : "0") << endl;
 
     {
       std::string indent( "gpgkey=");
@@ -859,23 +721,6 @@ namespace zypp
     return obj.dumpOn(str);
   }
 
-  std::ostream & operator<<( std::ostream & str, const RepoInfo::GpgCheck & obj )
-  {
-    switch ( obj )
-    {
-#define OUTS( V ) case RepoInfo::V: return str << #V; break
-      OUTS( GpgCheck::On );
-      OUTS( GpgCheck::Strict );
-      OUTS( GpgCheck::AllowUnsigned );
-      OUTS( GpgCheck::AllowUnsignedRepo );
-      OUTS( GpgCheck::AllowUnsignedPackage );
-      OUTS( GpgCheck::Default );
-      OUTS( GpgCheck::Off );
-      OUTS( GpgCheck::indeterminate );
-#undef OUTS
-    }
-    return str << "GpgCheck::UNKNOWN";
-  }
 
   /////////////////////////////////////////////////////////////////
 } // namespace zypp
