@@ -407,10 +407,6 @@ namespace zypp
                 {
                   cfg_known_services_path = Pathname(value);
                 }
-                else if ( entry == "varsdir" )
-                {
-                  cfg_vars_path = Pathname(value);
-                }
                 else if ( entry == "repo.add.probe" )
                 {
                   repo_add_probe = str::strToBool( value, repo_add_probe );
@@ -476,15 +472,15 @@ namespace zypp
                 }
                 else if ( entry == "gpgcheck" )
 		{
-		  gpgCheck.restoreToDefault( str::strToBool( value, gpgCheck ) );
+		  gpgCheck.set( str::strToBool( value, gpgCheck ) );
 		}
 		else if ( entry == "repo_gpgcheck" )
 		{
-		  repoGpgCheck.restoreToDefault( str::strToTriBool( value ) );
+		  repoGpgCheck.set( str::strToTriBool( value ) );
 		}
 		else if ( entry == "pkg_gpgcheck" )
 		{
-		  pkgGpgCheck.restoreToDefault( str::strToTriBool( value ) );
+		  pkgGpgCheck.set( str::strToTriBool( value ) );
 		}
                 else if ( entry == "vendordir" )
                 {
@@ -627,7 +623,6 @@ namespace zypp
     Pathname cfg_config_path;
     Pathname cfg_known_repos_path;
     Pathname cfg_known_services_path;
-    Pathname cfg_vars_path;
 
     Pathname cfg_vendor_path;
     Pathname cfg_multiversion_path;
@@ -656,9 +651,9 @@ namespace zypp
 
     Option<DownloadMode> commit_downloadMode;
 
-    DefaultOption<bool>		gpgCheck;
-    DefaultOption<TriBool>	repoGpgCheck;
-    DefaultOption<TriBool>	pkgGpgCheck;
+    Option<bool>	gpgCheck;
+    Option<TriBool>	repoGpgCheck;
+    Option<TriBool>	pkgGpgCheck;
 
     Option<bool>	solver_onlyRequires;
     Option<bool>	solver_allowVendorChange;
@@ -939,12 +934,6 @@ namespace zypp
         ? (configPath()/"services.d") : _pimpl->cfg_known_services_path );
   }
 
-  Pathname ZConfig::varsPath() const
-  {
-    return ( _pimpl->cfg_vars_path.empty()
-        ? (configPath()/"vars.d") : _pimpl->cfg_vars_path );
-  }
-
   Pathname ZConfig::vendorPath() const
   {
     return ( _pimpl->cfg_vendor_path.empty()
@@ -1011,19 +1000,14 @@ namespace zypp
   DownloadMode ZConfig::commit_downloadMode() const
   { return _pimpl->commit_downloadMode; }
 
+  bool ZConfig::gpgCheck() const
+  { return _pimpl->gpgCheck; }
 
-  bool ZConfig::gpgCheck() const			{ return _pimpl->gpgCheck; }
-  TriBool ZConfig::repoGpgCheck() const			{ return _pimpl->repoGpgCheck; }
-  TriBool ZConfig::pkgGpgCheck() const			{ return _pimpl->pkgGpgCheck; }
-
-  void ZConfig::setGpgCheck( bool val_r )		{ _pimpl->gpgCheck.set( val_r ); }
-  void ZConfig::setRepoGpgCheck( TriBool val_r )	{ _pimpl->repoGpgCheck.set( val_r ); }
-  void ZConfig::setPkgGpgCheck( TriBool val_r )		{ _pimpl->pkgGpgCheck.set( val_r ); }
-
-  void ZConfig::resetGpgCheck()				{ _pimpl->gpgCheck.restoreToDefault(); }
-  void ZConfig::resetRepoGpgCheck()			{ _pimpl->repoGpgCheck.restoreToDefault(); }
-  void ZConfig::resetPkgGpgCheck()			{ _pimpl->pkgGpgCheck.restoreToDefault(); }
+  TriBool ZConfig::repoGpgCheck() const
+  { return _pimpl->repoGpgCheck; }
 
+  TriBool ZConfig::pkgGpgCheck() const
+  { return _pimpl->pkgGpgCheck; }
 
   bool ZConfig::solver_onlyRequires() const
   { return _pimpl->solver_onlyRequires; }
