@@ -170,13 +170,6 @@ namespace zypp
        */
       Pathname knownServicesPath() const;
 
-      /**
-       * Path containing custom repo variable definitions (configPath()/vars.d).
-       * \see \ref zypp::repo::RepoVarExpand Repo variable expander
-       * \ingroup g_ZC_CONFIGFILES
-       */
-      Pathname varsPath() const;
-
       /**
        * Whether repository urls should be probed.
        / config option
@@ -293,18 +286,10 @@ namespace zypp
        * repositories \a .repo file will overwrite the defaults here.
        */
       //@{
-      bool gpgCheck() const;			///< Turn signature checking on/off (on)
-      TriBool repoGpgCheck() const;		///< Check repo matadata signatures (indeterminate - according to gpgcheck)
-      TriBool pkgGpgCheck() const;		///< Check rpm package signatures (indeterminate - according to gpgcheck)
-
-      void setGpgCheck( bool val_r );		///< Change the value
-      void setRepoGpgCheck( TriBool val_r );	///< Change the value
-      void setPkgGpgCheck( TriBool val_r );	///< Change the value
-
-      void resetGpgCheck();			///< Reset to the zconfig default
-      void resetRepoGpgCheck();			///< Reset to the zconfig default
-      void resetPkgGpgCheck();			///< Reset to the zconfig default
-     //@}
+      bool gpgCheck() const;		///< Turn signature checking on/off (on)
+      TriBool repoGpgCheck() const;	///< Check repo matadata signatures (indeterminate - according to gpgcheck)
+      TriBool pkgGpgCheck() const;	///< Check rpm package signatures (indeterminate - according to gpgcheck)
+      //@}
       //
       /**
        * Directory for equivalent vendor definitions  (configPath()/vendors.d)
