@@ -151,33 +151,6 @@ namespace
 }
 
 namespace zypp {
-
-  ///////////////////////////////////////////////////////////////////
-  namespace env
-  {
-    namespace
-    {
-      inline int getZYPP_MEDIA_CURL_IPRESOLVE()
-      {
-	int ret = 0;
-	if ( const char * envp = getenv( "ZYPP_MEDIA_CURL_IPRESOLVE" ) )
-	{
-	  WAR << "env set: $ZYPP_MEDIA_CURL_IPRESOLVE='" << envp << "'" << endl;
-	  if (      strcmp( envp, "4" ) == 0 )	ret = 4;
-	  else if ( strcmp( envp, "6" ) == 0 )	ret = 6;
-	}
-	return ret;
-      }
-    }
-
-    inline int ZYPP_MEDIA_CURL_IPRESOLVE()
-    {
-      static int _v = getZYPP_MEDIA_CURL_IPRESOLVE();
-      return _v;
-    }
-  } // namespace env
-  ///////////////////////////////////////////////////////////////////
-
   namespace media {
 
   namespace {
@@ -699,16 +672,6 @@ void MediaCurl::setupEasy()
       fillSettingsSystemProxy(_url, _settings);
   }
 
-  /** Force IPv4/v6 */
-  if ( env::ZYPP_MEDIA_CURL_IPRESOLVE() )
-  {
-    switch ( env::ZYPP_MEDIA_CURL_IPRESOLVE() )
-    {
-      case 4: SET_OPTION(CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4); break;
-      case 6: SET_OPTION(CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V6); break;
-    }
-  }
-
  /**
   * Connect timeout
   */
@@ -1003,13 +966,8 @@ void MediaCurl::getFileCopy( const Pathname & filename , const Pathname & target
     // unexpected exception
     catch (MediaException & excpt_r)
     {
-      media::DownloadProgressReport::Error reason = media::DownloadProgressReport::ERROR;
-      if( typeid(excpt_r) == typeid( media::MediaFileNotFoundException )  ||
-	  typeid(excpt_r) == typeid( media::MediaNotAFileException ) )
-      {
-	reason = media::DownloadProgressReport::NOT_FOUND;
-      }
-      report->finish(fileurl, reason, excpt_r.asUserHistory());
+      // FIXME: error number fix
+      report->finish(fileurl, zypp::media::DownloadProgressReport::ERROR, excpt_r.asUserHistory());
       ZYPP_RETHROW(excpt_r);
     }
   }
@@ -1063,6 +1021,7 @@ void MediaCurl::evaluateCurlCode( const Pathname &filename,
     else
       url = getFileUrl(filename);
     std::string err;
+    try
     {
       switch ( code )
       {
@@ -1110,7 +1069,6 @@ void MediaCurl::evaluateCurlCode( const Pathname &filename,
             ZYPP_THROW(MediaForbiddenException(url, msg403));
           }
           case 404:
-          case 410:
               ZYPP_THROW(MediaFileNotFoundException(_url, filename));
           }
 
@@ -1171,6 +1129,10 @@ void MediaCurl::evaluateCurlCode( const Pathname &filename,
       // uhm, no 0 code but unknown curl exception
       ZYPP_THROW(MediaCurlException(url, err, _curlError));
     }
+    catch (const MediaException & excpt_r)
+    {
+      ZYPP_RETHROW(excpt_r);
+    }
   }
   else
   {
