@@ -25,7 +25,6 @@
 #include "zypp/ZConfig.h"
 #include "zypp/RepoInfo.h"
 #include "zypp/RepoManager.h"
-#include "zypp/SrcPackage.h"
 
 #include "zypp/ZYppFactory.h"
 #include "zypp/Target.h"
@@ -53,58 +52,47 @@ namespace zypp
       return false;
     }
 
+
     ///////////////////////////////////////////////////////////////////
     /// \class PackageProvider::Impl
-    /// \brief PackageProvider implementation interface.
+    /// \brief PackageProvider implementation.
     ///////////////////////////////////////////////////////////////////
-    struct PackageProvider::Impl : private base::NonCopyable
+    class PackageProvider::Impl : private base::NonCopyable
     {
-      Impl() {}
-      virtual ~Impl() {}
-
-      /** Provide the package.
-       * The basic workflow.
-       * \throws Exception.
-       */
-      virtual ManagedFile providePackage() const = 0;
-
-      /** Provide the package if it is cached. */
-      virtual ManagedFile providePackageFromCache() const = 0;
-
-      /** Whether the package is cached. */
-      virtual bool isCached() const = 0;
-    };
-
-    ///////////////////////////////////////////////////////////////////
-    /// \class PackageProviderImpl<TPackage>
-    /// \brief PackageProvider implementation for \c Package and \c SrcPackage
-    ///////////////////////////////////////////////////////////////////
-    template <class TPackage>
-    class PackageProviderImpl : public PackageProvider::Impl
-    {
-      typedef typename TPackage::constPtr TPackagePtr;	// Package or SrcPackage
       typedef callback::UserData UserData;
     public:
       /** Ctor taking the Package to provide. */
-      PackageProviderImpl( RepoMediaAccess & access_r, const TPackagePtr & package_r,
-			   const PackageProviderPolicy & policy_r )
+      Impl( RepoMediaAccess & access_r,
+	    const Package::constPtr & package_r,
+	    const DeltaCandidates & deltas_r,
+	    const PackageProviderPolicy & policy_r )
       : _policy( policy_r )
       , _package( package_r )
+      , _deltas( deltas_r )
       , _access( access_r )
       , _retry(false)
       {}
 
-      virtual ~PackageProviderImpl() {}
+      virtual ~Impl() {}
+
+      /** Factory method providing the appropriate implementation.
+       * Called by PackageProvider ctor. Returned pointer should be
+       * immediately wrapped into a smartpointer.
+       */
+      static Impl * factoryMake( RepoMediaAccess & access_r,
+				 const Package::constPtr & package_r,
+				 const DeltaCandidates & deltas_r,
+				 const PackageProviderPolicy & policy_r );
 
     public:
       /** Provide the package.
        * The basic workflow.
        * \throws Exception.
        */
-      virtual ManagedFile providePackage() const;
+      ManagedFile providePackage() const;
 
       /** Provide the package if it is cached. */
-      virtual ManagedFile providePackageFromCache() const
+      ManagedFile providePackageFromCache() const
       {
 	ManagedFile ret( doProvidePackageFromCache() );
 	if ( ! ( ret->empty() ||  _package->repoInfo().keepPackages() ) )
@@ -113,22 +101,24 @@ namespace zypp
       }
 
       /** Whether the package is cached. */
-      virtual bool isCached() const
+      bool isCached() const
       { return ! doProvidePackageFromCache()->empty(); }
 
     protected:
-      typedef PackageProviderImpl<TPackage>	Base;
+      typedef PackageProvider::Impl	Base;
       typedef callback::SendReport<repo::DownloadResolvableReport>	Report;
 
       /** Lookup the final rpm in cache.
        *
-       * A cache hit will return a non empty ManagedFile and an empty one on cache miss.
+       * A non empty ManagedFile will be returned to the caller.
        *
        * \note File disposal depending on the repos keepPackages setting
        * are not set here, but in \ref providePackage or \ref providePackageFromCache.
+       *
+       * \note The provoided default implementation returns an empty ManagedFile
+       * (cache miss).
        */
-      ManagedFile doProvidePackageFromCache() const
-      { return ManagedFile( _package->cachedLocation() ); }
+      virtual ManagedFile doProvidePackageFromCache() const = 0;
 
       /** Actually provide the final rpm.
        * Report start/problem/finish and retry loop are hadled by \ref providePackage.
@@ -144,15 +134,7 @@ namespace zypp
        * \note The provided default implementation retrieves the packages default
        * location.
        */
-      virtual ManagedFile doProvidePackage() const
-      {
-	ManagedFile ret;
-	OnMediaLocation loc = _package->location();
-
-	ProvideFilePolicy policy;
-	policy.progressCB( bind( &Base::progressPackageDownload, this, _1 ) );
-	return _access.provideFile( _package->repoInfo(), loc, policy );
-      }
+      virtual ManagedFile doProvidePackage() const = 0;
 
     protected:
       /** Access to the DownloadResolvableReport */
@@ -165,7 +147,7 @@ namespace zypp
 
       typedef target::rpm::RpmDb RpmDb;
 
-      RpmDb::CheckPackageResult packageSigCheck( const Pathname & path_r, bool isMandatory_r, UserData & userData ) const
+      RpmDb::CheckPackageResult packageSigCheck( const Pathname & path_r, UserData & userData ) const
       {
 	if ( !_target )
 	  _target = getZYpp()->getTarget();
@@ -173,14 +155,7 @@ namespace zypp
 	RpmDb::CheckPackageResult ret = RpmDb::CHK_ERROR;
 	RpmDb::CheckPackageDetail detail;
 	if ( _target )
-	{
-	  ret = _target->rpmDb().checkPackageSignature( path_r, detail );
-	  if ( ret == RpmDb::CHK_NOSIG && !isMandatory_r )
-	  {
-	    WAR << "Relax CHK_NOSIG: Config says unsigned packages are OK" << endl;
-	    ret = RpmDb::CHK_OK;
-	  }
-	}
+	  ret = _target->rpmDb().checkPackage( path_r, detail );
 	else
 	  detail.push_back( RpmDb::CheckPackageDetail::value_type( ret, "OOps. Target is not initialized!" ) );
 
@@ -221,7 +196,8 @@ namespace zypp
 
     protected:
       PackageProviderPolicy	_policy;
-      TPackagePtr		_package;
+      Package::constPtr		_package;
+      DeltaCandidates		_deltas;
       RepoMediaAccess &		_access;
 
     private:
@@ -244,8 +220,24 @@ namespace zypp
     };
     ///////////////////////////////////////////////////////////////////
 
-    template <class TPackage>
-    ManagedFile PackageProviderImpl<TPackage>::providePackage() const
+    /** Default implementation (cache miss). */
+    ManagedFile PackageProvider::Impl::doProvidePackageFromCache() const
+    { return ManagedFile(); }
+
+    /** Default implementation (provide full package) */
+    ManagedFile PackageProvider::Impl::doProvidePackage() const
+    {
+      ManagedFile ret;
+      OnMediaLocation loc = _package->location();
+
+      ProvideFilePolicy policy;
+      policy.progressCB( bind( &Base::progressPackageDownload, this, _1 ) );
+      return _access.provideFile( _package->repoInfo(), loc, policy );
+    }
+
+    ///////////////////////////////////////////////////////////////////
+
+    ManagedFile PackageProvider::Impl::providePackage() const
     {
       ScopedGuard guardReport( newReport() );
 
@@ -295,7 +287,6 @@ namespace zypp
 
       MIL << "provide Package " << _package << endl;
       Url url = * info.baseUrlsBegin();
-      try {
       do {
         _retry = false;
 	if ( ! ret->empty() )
@@ -311,35 +302,12 @@ namespace zypp
 	    if ( info.pkgGpgCheck() )
 	    {
 	      UserData userData( "pkgGpgCheck" );
-	      ResObject::constPtr roptr( _package );	// gcc6 needs it more explcit. Has problem deducing
-	      userData.set( "ResObject", roptr );	// a type for '_package->asKind<ResObject>()'...
-	      /*legacy:*/userData.set( "Package", roptr->asKind<Package>() );
+	      userData.set( "Package", _package );
 	      userData.set( "Localpath", ret.value() );
-#if ( 1 )
-	      bool pkgGpgCheckIsMandatory = info.pkgGpgCheckIsMandatory();
-	      if ( str::startsWith( VERSION, "16.15." ) )
-	      {
-		// BSC#1038984: For a short period of time, libzypp-16.15.x
-		// will silently accept unsigned packages IFF a repositories gpgcheck
-		// configuration is explicitly turned OFF like this:
-		//     gpgcheck      = 0
-		//     repo_gpgcheck = 0
-		//     pkg_gpgcheck  = 1
-		// This will allow some already released products to adapt to the behavioral
-		// changes introduced by fixing BSC#1038984, while systems with a default
-		// configuration (gpgcheck = 1) already benefit from the fix.
-		// With libzypp-16.16.x the above configuration will reject unsigned packages
-		// as it should.
-		if ( pkgGpgCheckIsMandatory && !info.gpgCheck() && !info.repoGpgCheck() )
-		  pkgGpgCheckIsMandatory = false;
-	      }
-	      RpmDb::CheckPackageResult res = packageSigCheck( ret, pkgGpgCheckIsMandatory, userData );
-#else
-	      RpmDb::CheckPackageResult res = packageSigCheck( ret, info.pkgGpgCheckIsMandatory(), userData );
-#endif
+	      RpmDb::CheckPackageResult res = packageSigCheck( ret, userData );
 	      // publish the checkresult, even if it is OK. Apps may want to report something...
 	      report()->pkgGpgCheck( userData );
-
+USR << "CHK: " << res << endl;
 	      if ( res != RpmDb::CHK_OK )
 	      {
 		if ( userData.hasvalue( "Action" ) )	// pkgGpgCheck report provided an user error action
@@ -362,7 +330,6 @@ namespace zypp
 		    case RpmDb::CHK_FAIL:	// Signature does not verify
 		    case RpmDb::CHK_NOTTRUSTED:	// Signature is OK, but key is not trusted
 		    case RpmDb::CHK_ERROR:	// File does not exist or can't be opened
-		    case RpmDb::CHK_NOSIG:	// File is unsigned
 		    default:
 		      // report problem (w. details), throw if to abort, else retry/ignore
 		      defaultReportSignatureError( res, str::Str() << userData.get<RpmDb::CheckPackageDetail>( "CheckPackageDetail" ) );
@@ -431,16 +398,6 @@ namespace zypp
               }
           }
       } while ( _retry );
-      } catch(...){
-	// bsc#1045735: Be sure no invalid files stay in the cache!
-	// TODO: It would be better to provide a filechecker passed to the
-	// fetcher that performs the pkgGpgCheck. This way a bad file would be
-	// discarded before it's moved to the cache.
-	// For now make sure the file gets deleted (even if keeppackages=1).
-	if ( ! ret->empty() )
-	  ret.setDispose( filesystem::unlink );
-	throw;
-      }
 
       report()->finish( _package, repo::DownloadResolvableReport::NO_ERROR, std::string() );
       MIL << "provided Package " << _package << " at " << ret << endl;
@@ -450,20 +407,21 @@ namespace zypp
 
     ///////////////////////////////////////////////////////////////////
     /// \class RpmPackageProvider
-    /// \brief RPM PackageProvider implementation (with deltarpm processing).
+    /// \brief RPM PackageProvider implementation.
     ///////////////////////////////////////////////////////////////////
-    class RpmPackageProvider : public PackageProviderImpl<Package>
+    class RpmPackageProvider : public PackageProvider::Impl
     {
     public:
       RpmPackageProvider( RepoMediaAccess & access_r,
 			  const Package::constPtr & package_r,
 			  const DeltaCandidates & deltas_r,
 			  const PackageProviderPolicy & policy_r )
-      : PackageProviderImpl<Package>( access_r, package_r, policy_r )
-      , _deltas( deltas_r )
+      : PackageProvider::Impl( access_r, package_r, deltas_r, policy_r )
       {}
 
     protected:
+      virtual ManagedFile doProvidePackageFromCache() const;
+
       virtual ManagedFile doProvidePackage() const;
 
     private:
@@ -479,12 +437,14 @@ namespace zypp
 
       bool queryInstalled( const Edition & ed_r = Edition() ) const
       { return _policy.queryInstalled( _package->name(), ed_r, _package->arch() ); }
-
-    private:
-      DeltaCandidates		_deltas;
     };
     ///////////////////////////////////////////////////////////////////
 
+    ManagedFile RpmPackageProvider::doProvidePackageFromCache() const
+    {
+      return ManagedFile( _package->cachedLocation() );
+    }
+
     ManagedFile RpmPackageProvider::doProvidePackage() const
     {
       Url url;
@@ -564,59 +524,56 @@ namespace zypp
       return ManagedFile( destination, filesystem::unlink );
     }
 
+#if 0
+    ///////////////////////////////////////////////////////////////////
+    /// \class PluginPackageProvider
+    /// \brief Plugin PackageProvider implementation.
+    ///
+    /// Basically downloads the default package and calls a
+    /// 'stem'2rpm plugin to cteate the final .rpm package.
+    ///////////////////////////////////////////////////////////////////
+    class PluginPackageProvider : public PackageProvider::Impl
+    {
+    public:
+      PluginPackageProvider( const std::string & stem_r,
+			     RepoMediaAccess & access_r,
+			     const Package::constPtr & package_r,
+			     const DeltaCandidates & deltas_r,
+			     const PackageProviderPolicy & policy_r )
+      : Base( access_r, package_r, deltas_r, policy_r )
+      {}
+
+    protected:
+      virtual ManagedFile doProvidePackageFromCache() const
+      {
+	return Base::doProvidePackageFromCache();
+      }
+
+      virtual ManagedFile doProvidePackage() const
+      {
+	return Base::doProvidePackage();
+      }
+    };
+    ///////////////////////////////////////////////////////////////////
+#endif
+
     ///////////////////////////////////////////////////////////////////
     //	class PackageProvider
     ///////////////////////////////////////////////////////////////////
-    namespace factory
+
+    PackageProvider::Impl * PackageProvider::Impl::factoryMake( RepoMediaAccess & access_r,
+								const Package::constPtr & package_r,
+								const DeltaCandidates & deltas_r,
+								const PackageProviderPolicy & policy_r )
     {
-      inline PackageProvider::Impl * make( RepoMediaAccess & access_r, const PoolItem & pi_r,
-					   const DeltaCandidates & deltas_r,
-					   const PackageProviderPolicy & policy_r )
-      {
-	if ( pi_r.isKind<Package>() )
-	  return new RpmPackageProvider( access_r, pi_r->asKind<Package>(), deltas_r, policy_r );
-	else if ( pi_r.isKind<SrcPackage>() )
-	  return new PackageProviderImpl<SrcPackage>( access_r, pi_r->asKind<SrcPackage>(), policy_r );
-	else
-	  ZYPP_THROW( Exception( str::Str() << "Don't know how to cache non-package " << pi_r.asUserString() ) );
-      }
+      return new RpmPackageProvider( access_r, package_r, deltas_r, policy_r );
+    }
 
-      inline PackageProvider::Impl * make( RepoMediaAccess & access_r, const PoolItem & pi_r,
-						  const PackageProviderPolicy & policy_r )
-      {
-	if ( pi_r.isKind<Package>() )
-	  return new PackageProviderImpl<Package>( access_r, pi_r->asKind<Package>(), policy_r );
-	else if ( pi_r.isKind<SrcPackage>() )
-	  return new PackageProviderImpl<SrcPackage>( access_r, pi_r->asKind<SrcPackage>(), policy_r );
-	else
-	  ZYPP_THROW( Exception( str::Str() << "Don't know how to cache non-package " << pi_r.asUserString() ) );
-      }
-
-      inline PackageProvider::Impl * make( RepoMediaAccess & access_r, const Package::constPtr & package_r,
-					   const DeltaCandidates & deltas_r,
-					   const PackageProviderPolicy & policy_r )
-      { return new RpmPackageProvider( access_r, package_r, deltas_r, policy_r ); }
-
-    } // namespace factory
-    ///////////////////////////////////////////////////////////////////
-
-    PackageProvider::PackageProvider( RepoMediaAccess & access_r, const PoolItem & pi_r,
-				      const DeltaCandidates & deltas_r, const PackageProviderPolicy & policy_r )
-
-    : _pimpl( factory::make( access_r, pi_r, deltas_r, policy_r ) )
-    {}
-
-    PackageProvider::PackageProvider( RepoMediaAccess & access_r, const PoolItem & pi_r,
-				      const PackageProviderPolicy & policy_r )
-    : _pimpl( factory::make( access_r, pi_r, policy_r ) )
-    {}
-
-    /* legacy */
     PackageProvider::PackageProvider( RepoMediaAccess & access_r,
 				      const Package::constPtr & package_r,
 				      const DeltaCandidates & deltas_r,
 				      const PackageProviderPolicy & policy_r )
-    : _pimpl( factory::make( access_r, package_r, deltas_r, policy_r ) )
+    : _pimpl( Impl::factoryMake( access_r, package_r, deltas_r, policy_r ) )
     {}
 
     PackageProvider::~PackageProvider()
