@@ -382,9 +382,9 @@ namespace zypp
       return isSystem() && myPool().isOnSystemByAuto( ident() );
     }
 
-    bool Solvable::identIsAutoInstalled( const IdString & ident_r )
+    bool Solvable::identIsAutoInstalled() const
     {
-      return myPool().isOnSystemByAuto( ident_r );
+      return myPool().isOnSystemByAuto( ident() );
     }
 
     bool Solvable::multiversionInstall() const
