@@ -1234,7 +1234,7 @@ namespace zypp
       if ( ! policy_r.dryRun() || policy_r.downloadMode() == DownloadOnly )
       {
 	// Prepare the package cache. Pass all items requiring download.
-        CommitPackageCache packageCache;
+        CommitPackageCache packageCache( root() );
 	packageCache.setCommitList( steps.begin(), steps.end() );
 
         bool miss = false;
@@ -1264,7 +1264,22 @@ namespace zypp
               ManagedFile localfile;
               try
               {
-		localfile = packageCache.get( pi );
+		// TODO: unify packageCache.get for Package and SrcPackage
+		if ( pi->isKind<Package>() )
+		{
+		  localfile = packageCache.get( pi );
+		}
+		else if ( pi->isKind<SrcPackage>() )
+		{
+		  repo::RepoMediaAccess access;
+		  repo::SrcPackageProvider prov( access );
+		  localfile = prov.provideSrcPackage( pi->asKind<SrcPackage>() );
+		}
+		else
+		{
+		  INT << "Don't know howto cache: Neither Package nor SrcPackage: " << pi << endl;
+		  continue;
+		}
                 localfile.resetDispose(); // keep the package file in the cache
               }
               catch ( const AbortRequestException & exp )
