@@ -150,10 +150,7 @@ namespace zypp
        */
       PoolItem highestAvailableVersionObj() const;
 
-      /** Whether this \ref ident is flagged as AutoInstalled. */
-      bool identIsAutoInstalled() const;
-
-      /** \c True if \a rhs is installed and one with the same content is available.
+     /** \c True if \a rhs is installed and one with the same content is available.
        * Basically the same name, edition, arch, vendor and buildtime.
        * \see \ref sat::Solvable::identical
        */
